from deprogressapi import FormalProgressInterface, ProgressReport
from digitalearth_floodmask_update.update_flood_events_routine import FLOOD_UPDATE_PIPELINE

import asyncio
import json


class ProgressConsoleHandler(FormalProgressInterface):
    def send(self, report: str):
        print(json.dumps(json.loads(report), indent=2))
        print('=======================================================================================================')


# USAGE EXAMPLE
if __name__ == "__main__":
    default_config = {
        "base_url": "https://emergency.copernicus.eu",
        "activations_list_url": "https://emergency.copernicus.eu/mapping/list-of-activations-rapid",
        "activation_filters": {"affected_countries": ["DE"]},
        "geoserver_url": "http://rz-vm154.gfz-potsdam.de:8080/geoserver",
        "username": "***enter-geoserver-username-here***",
        "password": "***enter-geoserver-password-here***",
        "workspace": "flood",
        "digital_elevation_model": "digitalearth:de_dem25m",
        "enforce_xy_order": True,
        "min_recency_in_days": 40
    }

    pr: ProgressReport = ProgressReport('pipeline progress', ProgressConsoleHandler())

    # workaround to fix issues with running requests-html outside main thread
    async def run_pipeline():
        FLOOD_UPDATE_PIPELINE.set_progress_report(pr)
        return FLOOD_UPDATE_PIPELINE.initialize_and_run(default_config)

    loop = asyncio.new_event_loop()
    asyncio.set_event_loop(loop)
    loop.run_until_complete(run_pipeline())

    output, execution_status = FLOOD_UPDATE_PIPELINE.initialize_and_run(default_config)

    pr.complete()

    print(execution_status)
    print(output)

